@@ -5,4 +5,4 @@ Created on Fri Aug 14 14:41:53 2020
 @author: supakrni
 """
 
-from pyrmvtxt import removetxt
+from pyrmvtxt.rmvtxt_code import removetxt
